#!/bin/sh

if [ $# -ne 1 ]
then
echo "Usage: InstallPatch.sh FullPathOfBundle"
echo "Example: InstallPatch.sh /path_to_bundle/xxx.zip"
return 1
fi

CheckSystemVersion()
{
version=`cat /etc/vmware/hostd/ft-hostd-version | grep product-version | awk -F" " {'printf("%s\n",$3)'}`
}

#INSTALL ESXi 4.x Patch Functions

CheckInstalledProviders()
{
	esxupdate --vib-view query > /tmp/providerlist
	filetrans=`cat /tmp/providerlist | grep '\<installed' | grep filetrans | awk -F' ' {'printf("%s\n",$1)'}`
	fwupdate=`cat /tmp/providerlist | grep '\<installed' | grep fwupdate | awk -F' ' {'printf("%s\n",$1)'}`
	concretejob=`cat /tmp/providerlist | grep '\<installed' | grep concretejob | awk -F' ' {'printf("%s\n",$1)'}`
	immpassthru=`cat /tmp/providerlist | grep '\<installed' | grep immpassthru | awk -F' ' {'printf("%s\n",$1)'}`
	ipptools=`cat /tmp/providerlist | grep '\<installed' | grep ipptools | awk -F' ' {'printf("%s\n",$1)'}`
	fupb=`cat /tmp/providerlist | grep '\<installed' | grep fupb | awk -F' ' {'printf("%s\n",$1)'}`
	fchba=`cat /tmp/providerlist | grep '\<installed' | grep cross_qlogic-fchba | awk -F' ' {'printf("%s\n",$1)'}`
}



RemoveProviders()
{
CheckInstalledProviders

for name in $filetrans $fwupdate $concretejob $immpassthru $ipptools $fupb $fchba
do
	echo "esxupdate -b $name remove --maintenancemode"
	esxupdate -b $name remove --maintenancemode
done
echo "Verifying if all providers have been removed."
CheckInstalledProviders
for name in $filetrans $fwupdate $concretejob $immpassthru $ipptools $fupb $fchba
do 
	if [ "$name" != "" ]
	then
		echo "Uninstallation of $name failed, please run the installation script again."
		rm -rf /tmp/providerlist
		exit 1
	fi
done
rm -rf /tmp/providerlist
}

InstallESXi4Patch()
{
echo "Removing providers: it may take a while..."
RemoveProviders
echo  "Start installation: it may take a while... "
#esxupdate --bundle $1 update  --maintenancemode  --nosigcheck
esxupdate --bundle $1 update  --maintenancemode
}





#INSTALL ESXi 5.x Patch Functions

RemovefchbaLSIProvider()
{
esxcli software vib list > /tmp/providerlist
fchba=`cat /tmp/providerlist | grep fchba | awk -F' ' {'printf ("%s\n", $1)'}`
LSIProvider=`cat /tmp/providerlist | grep LSIProvider | awk -F' ' {'printf ("%s\n", $1)'}`
rm -rf /tmp/providerlist
/etc/init.d/sfcbd-watchdog stop
if [ "$fchba" = "provider-fchba" ]
then
esxcli software vib remove -n ${fchba} --maintenance-mode
fi
if [ "$LSIProvider" = "LSIProvider" ]
then
esxcli software vib remove -n ${LSIProvider} --maintenance-mode
fi
/etc/init.d/sfcbd-watchdog start
}

#Delete the extracted files from 5.x Patch
CleanInstallation()
{
files=`unzip -l $1 | grep .xml | awk -F " " '{print $4}'`
for file in $files
do
rm -f /tmp/$file
done
}

InstallPatch()
{
if [ -f $1 ];
then
  CheckSystemVersion
  echo "System version is $version"
  #majVersion=${version:0:1}
  case "$version" in
  5.1* )
  unzip -q -o $1 -x *.vib -d /tmp/
  if grep -q 5.1 /tmp/vendor-index.xml
  then
	RemovefchbaLSIProvider
	echo "Installing patch under $1"
	#esxcli software vib install -d  $1 --no-sig-check
	esxcli software vib install -d  $1
  else
	echo "System version $version is not compatible with your bundle $1, please contact with your vendor."
  fi
  echo "Cleanning the installation files...."
  CleanInstallation $1;;
  5.0* )
  unzip -q -o $1 -x *.vib -d /tmp/
  if grep -q 5.0 /tmp/vendor-index.xml
  then
	RemovefchbaLSIProvider
	echo "Installing patch under $1"
	#esxcli software vib install -d  $1 --no-sig-check
	esxcli software vib install -d  $1
  else
	echo "System version $version is not compatible with your bundle $1, please contact with your vendor."
  fi
  echo "Cleanning the installation files...."
  CleanInstallation $1;;
  4* )
  echo "Installing patch under $1"
  InstallESXi4Patch $1;;
  * )
  echo "Unknow System, please contact with your system administrator for assistance";;
  esac
fi
}


InstallPatch $1

